.. _node-yaml:

Node code lists
***************

The codes in these lists denote **regions** and **countries**.

When loaded using :func:`.get_codes`, the :attr:`.Code.child` attribute is a list of child codes.
See the function documentation for how to retrieve these.

.. contents::
   :local:

32-region aggregation (``R32``)
===============================

.. literalinclude:: ../../message_ix_models/data/node/R32.yaml
   :language: yaml

14-region aggregation (``R14``)
===============================

.. literalinclude:: ../../message_ix_models/data/node/R14.yaml
   :language: yaml

11-region aggregation (``R11``)
===============================

.. literalinclude:: ../../message_ix_models/data/node/R11.yaml
   :language: yaml

5-region aggregation (``RCP``)
==============================

.. literalinclude:: ../../message_ix_models/data/node/RCP.yaml
   :language: yaml
